
***************
Getting started
***************


Installation
------------

.. grid:: 2

    .. grid-item-card:: Installing with conda
       :text-align: center
       :columns: 12

       Kalpy is available on :xref:`conda_forge` and can be installed with Anaconda or Miniconda:

       .. code-block:: bash

          conda config --add channels conda-forge
          conda install kalpy

       +++

       .. button-link:: https://docs.conda.io/projects/conda/en/latest/user-guide/install/index.html
          :color: primary
          :expand:

          Install Conda


    .. grid-item-card:: In-depth instructions
       :text-align: center

       Using :ref:`Docker <docker_installation>`? Want to :ref:`install via source <source_installation>`?

       +++

       .. button-ref:: installation
          :expand:
          :color: primary
          :ref-type: doc

          To the installation guide



.. toctree::
   :maxdepth: 1
   :hidden:

   installation
